@@ -1,6 +1,7 @@
-use crate::domain::error::{DomainError, DomainResult};
+use crate::domain::error::DomainResult;
+use crate::util::path::expand_path;
 use serde::{Deserialize, Serialize};
-use serial_test::serial;
+use std::collections::HashMap;
 use std::path::{Path, PathBuf};
 use tracing::{debug, instrument, trace, warn};
 
@@ -21,12 +22,28 @@ pub struct FzfOpts {
     /// Whether to hide URLs in the fuzzy finder (default: false)
     #[serde(default)]
     pub no_url: bool,
+
+    /// Whether to show default action in the fuzzy finder (default: true)
+    #[serde(default = "default_show_action")]
+    pub show_action: bool,
+
+    /// Whether to show file info (path and mtime) for file-imported bookmarks (default: true)
+    #[serde(default = "default_show_file_info")]
+    pub show_file_info: bool,
 }
 
 fn default_height() -> String {
     "50%".to_string()
 }
 
+fn default_show_action() -> bool {
+    true
+}
+
+fn default_show_file_info() -> bool {
+    true
+}
+
 impl Default for FzfOpts {
     fn default() -> Self {
         Self {
@@ -34,6 +51,27 @@ impl Default for FzfOpts {
             reverse: false,
             show_tags: false,
             no_url: false,
+            show_action: default_show_action(),
+            show_file_info: default_show_file_info(),
+        }
+    }
+}
+
+#[derive(Debug, Clone, Deserialize, Serialize)]
+pub struct ShellOpts {
+    /// Whether to use interactive mode for shell script execution (default: true)
+    #[serde(default = "default_interactive")]
+    pub interactive: bool,
+}
+
+fn default_interactive() -> bool {
+    true
+}
+
+impl Default for ShellOpts {
+    fn default() -> Self {
+        Self {
+            interactive: default_interactive(),
         }
     }
 }
@@ -48,22 +86,26 @@ pub struct Settings {
     #[serde(default)]
     pub fzf_opts: FzfOpts,
 
+    /// Options for shell script execution
+    #[serde(default)]
+    pub shell_opts: ShellOpts,
+
+    /// Base paths for file imports (e.g., SCRIPTS_HOME="$HOME/scripts")
+    #[serde(default)]
+    pub base_paths: HashMap<String, String>,
+
     /// Tracks configuration source (not serialized)
     #[serde(skip)]
     pub config_source: ConfigSource,
 }
 
-#[derive(Debug, Clone, PartialEq, Deserialize, Serialize)]
+#[derive(Debug, Clone, PartialEq, Deserialize, Serialize, Default)]
 pub enum ConfigSource {
+    #[default]
     Default,
     ConfigFile,
     Environment,
 }
-impl Default for ConfigSource {
-    fn default() -> Self {
-        ConfigSource::Default
-    }
-}
 
 fn default_db_path() -> String {
     // Try to get the home directory
@@ -99,12 +141,14 @@ impl Default for Settings {
         Self {
             db_url: default_db_path(),
             fzf_opts: FzfOpts::default(),
+            shell_opts: ShellOpts::default(),
+            base_paths: HashMap::new(),
             config_source: ConfigSource::Default,
         }
     }
 }
 
-// Parse FZF options from a string like "--height 99% --reverse --show-tags"
+// Parse FZF options from a string like "--height 99% --reverse --show-tags --no-action"
 fn parse_fzf_opts(opts_str: &str) -> FzfOpts {
     let mut opts = FzfOpts::default();
 
@@ -125,6 +169,13 @@ fn parse_fzf_opts(opts_str: &str) -> FzfOpts {
             "--no-url" => {
                 opts.no_url = true;
             }
+            "--no-action" => {
+                // Add handling for the new option
+                opts.show_action = false;
+            }
+            "--no-file-info" => {
+                opts.show_file_info = false;
+            }
             _ => {} // Ignore unknown options
         }
     }
@@ -151,6 +202,9 @@ pub fn load_settings(config_file: Option<&Path>) -> DomainResult<Settings> {
                     file_settings.config_source = ConfigSource::ConfigFile;
                     settings = file_settings;
 
+                    // Expand db_url path after loading from file
+                    expand_db_url(&mut settings);
+
                     trace!("Successfully loaded settings from specified file");
                 } else {
                     warn!("Failed to parse config file: {:?}", path);
@@ -177,7 +231,7 @@ pub fn load_settings(config_file: Option<&Path>) -> DomainResult<Settings> {
     ];
 
     // Load from config files if they exist
-    let mut found_config = false;
+    // let mut found_config = false;
     for config_path in config_sources.iter().flatten() {
         if config_path.exists() {
             trace!("Loading config from: {:?}", config_path);
@@ -187,7 +241,11 @@ pub fn load_settings(config_file: Option<&Path>) -> DomainResult<Settings> {
                     // Update settings with values from file and mark as loaded
                     file_settings.config_source = ConfigSource::ConfigFile;
                     settings = file_settings;
-                    found_config = true;
+                    
+                    // Expand db_url path after loading from file
+                    expand_db_url(&mut settings);
+                    
+                    // found_config = true;
                     break; // Use the first found configuration file
                 }
             }
@@ -205,6 +263,11 @@ pub fn load_settings(config_file: Option<&Path>) -> DomainResult<Settings> {
     Ok(settings)
 }
 
+// Helper function to expand the database URL path
+fn expand_db_url(settings: &mut Settings) {
+    settings.db_url = expand_path(&settings.db_url);
+}
+
 // Extract environment variable application to a separate function
 fn apply_env_overrides(settings: &mut Settings) {
     let mut used_env_vars = false;
@@ -221,6 +284,15 @@ fn apply_env_overrides(settings: &mut Settings) {
         used_env_vars = true;
     }
 
+    if let Ok(shell_interactive) = std::env::var("BKMR_SHELL_INTERACTIVE") {
+        trace!(
+            "Using BKMR_SHELL_INTERACTIVE from environment: {}",
+            shell_interactive
+        );
+        settings.shell_opts.interactive = shell_interactive.to_lowercase() == "true";
+        used_env_vars = true;
+    }
+
     // If we've used environment variables and were using defaults before,
     // update the source
     if used_env_vars && settings.config_source == ConfigSource::Default {
@@ -235,12 +307,47 @@ pub fn generate_default_config() -> String {
         .unwrap_or_else(|_| "# Error generating default configuration".to_string())
 }
 
+/// Get the path to the user's config file
+pub fn get_config_file_path() -> Option<PathBuf> {
+    dirs::home_dir().map(|p| p.join(".config/bkmr/config.toml"))
+}
+
+/// Check if a base path exists in configuration
+pub fn has_base_path(settings: &Settings, name: &str) -> bool {
+    settings.base_paths.contains_key(name)
+}
+
+/// Resolve a file path with base path variables
+pub fn resolve_file_path(settings: &Settings, path: &str) -> String {
+    let mut resolved = path.to_string();
+
+    // Replace base path variables
+    for (name, base_path) in &settings.base_paths {
+        let var_pattern = format!("${}", name);
+        if resolved.contains(&var_pattern) {
+            let expanded_base =
+                shellexpand::full(base_path).unwrap_or(std::borrow::Cow::Borrowed(base_path));
+            resolved = resolved.replace(&var_pattern, &expanded_base);
+        }
+    }
+
+    // Also handle standard environment variables
+    match shellexpand::full(&resolved) {
+        Ok(expanded) => expanded.to_string(),
+        Err(_) => resolved,
+    }
+}
+
+/// Create a file path with base path variable
+pub fn create_file_path_with_base(base_path_name: &str, relative_path: &str) -> String {
+    format!("${}/{}", base_path_name, relative_path)
+}
+
 // At the end of config.rs file
 #[cfg(test)]
 mod tests {
     use super::*;
     use crate::util::testing::EnvGuard;
-    use serial_test::serial;
     use std::env;
     use std::fs;
     use std::path::Path;
@@ -255,8 +362,7 @@ mod tests {
     }
 
     #[test]
-    #[serial]
-    fn test_default_settings() {
+    fn given_no_config_file_when_load_settings_then_uses_defaults() {
         let _guard = EnvGuard::new();
         env::remove_var("BKMR_DB_URL");
         env::remove_var("BKMR_FZF_OPTS");
@@ -272,8 +378,7 @@ mod tests {
     }
 
     #[test]
-    #[serial]
-    fn test_specific_config_file() {
+    fn given_custom_config_file_when_load_settings_then_uses_file_values() {
         let _guard = EnvGuard::new();
         env::remove_var("BKMR_DB_URL");
         env::remove_var("BKMR_FZF_OPTS");
@@ -306,8 +411,7 @@ mod tests {
     }
 
     #[test]
-    #[serial]
-    fn test_environment_variables_override_config_file() {
+    fn given_env_vars_and_config_file_when_load_settings_then_env_vars_override() {
         let _guard = EnvGuard::new();
 
         // Create a custom config file
@@ -342,8 +446,7 @@ mod tests {
     }
 
     #[test]
-    #[serial]
-    fn test_nonexistent_config_file() {
+    fn given_nonexistent_config_file_when_load_settings_then_uses_defaults() {
         let _guard = EnvGuard::new();
         env::remove_var("BKMR_DB_URL");
         env::remove_var("BKMR_FZF_OPTS");
@@ -361,8 +464,7 @@ mod tests {
     }
 
     #[test]
-    #[serial]
-    fn test_environment_variables_override() {
+    fn given_env_vars_when_load_settings_then_overrides_defaults() {
         let _guard = EnvGuard::new();
 
         // Set environment variables
@@ -380,8 +482,7 @@ mod tests {
     }
 
     #[test]
-    #[serial]
-    fn test_partial_environment_override() {
+    fn given_partial_env_vars_when_load_settings_then_overrides_only_specified() {
         let _guard = EnvGuard::new();
 
         // Set only DB URL
@@ -397,8 +498,7 @@ mod tests {
     }
 
     #[test]
-    #[serial]
-    fn test_parse_fzf_opts() {
+    fn given_fzf_option_string_when_parse_fzf_opts_then_returns_parsed_options() {
         // Test with all options
         let opts = parse_fzf_opts("--height 80% --reverse --show-tags --no-url");
         assert_eq!(opts.height, "80%");
@@ -427,8 +527,7 @@ mod tests {
     }
 
     #[test]
-    #[serial]
-    fn test_config_file_loading() {
+    fn given_config_file_content_when_create_settings_then_matches_expected_values() {
         let _guard = EnvGuard::new();
         env::remove_var("BKMR_DB_URL");
         env::remove_var("BKMR_FZF_OPTS");
@@ -444,11 +543,10 @@ mod tests {
         no_url = false
         "#;
 
-        let (temp_dir, config_path) = create_temp_config_file(config_content);
+        let (temp_dir, _config_path) = create_temp_config_file(config_content);
 
-        // Mock the config dir location for testing
-        let original_config_dir = dirs::config_dir();
-        // Note: In a real test, you'd need to mock dirs::config_dir to return your temp dir
+        let _original_config_dir = dirs::config_dir();
+        // todo: In a real test, you'd need to mock dirs::config_dir to return your temp dir
         // For this example, we'll skip actually loading from the file
 
         let settings = Settings {
@@ -458,7 +556,11 @@ mod tests {
                 reverse: true,
                 show_tags: true,
                 no_url: false,
+                show_action: true,
+                show_file_info: true,
             },
+            shell_opts: ShellOpts { interactive: true },
+            base_paths: HashMap::new(),
             config_source: ConfigSource::ConfigFile,
         };
 
@@ -474,8 +576,7 @@ mod tests {
     }
 
     #[test]
-    #[serial]
-    fn test_environment_overrides_config_file() {
+    fn given_env_vars_and_config_content_when_load_settings_then_env_overrides_config() {
         let _guard = EnvGuard::new();
 
         // Set environment variables
@@ -493,9 +594,7 @@ mod tests {
         no_url = false
         "#;
 
-        let (temp_dir, config_path) = create_temp_config_file(config_content);
-
-        // Mock the config dir location for testing (same note as above)
+        let (temp_dir, _config_path) = create_temp_config_file(config_content);
 
         // Simulate loading with environment variables overriding config file
         let settings = load_settings(None).unwrap();
@@ -511,10 +610,38 @@ mod tests {
     }
 
     #[test]
-    #[serial]
-    fn test_default_db_path() {
+    fn given_no_custom_path_when_default_db_path_then_contains_bkmr_db() {
         // Test the default path generation
         let path = default_db_path();
         assert!(path.contains("bkmr.db"));
     }
+
+    #[test]
+    fn given_shell_interactive_env_var_when_load_settings_then_overrides_default() {
+        let _guard = EnvGuard::new();
+
+        // Set environment variable to disable interactive mode
+        env::set_var("BKMR_SHELL_INTERACTIVE", "false");
+        env::remove_var("BKMR_DB_URL");
+        env::remove_var("BKMR_FZF_OPTS");
+
+        let settings = load_settings(None).unwrap();
+
+        // Check that shell interactive was overridden
+        assert!(
+            !settings.shell_opts.interactive,
+            "Should disable interactive mode via environment"
+        );
+
+        // Set environment variable to enable interactive mode
+        env::set_var("BKMR_SHELL_INTERACTIVE", "true");
+
+        let settings = load_settings(None).unwrap();
+
+        // Check that shell interactive was overridden
+        assert!(
+            settings.shell_opts.interactive,
+            "Should enable interactive mode via environment"
+        );
+    }
 }
