@@ -10,7 +10,7 @@ use std::collections::HashSet;
 use std::fmt;
 
 /// Represents a bookmark domain entity
-#[derive(Builder, Debug, Clone, PartialEq)]
+#[derive(Builder, Clone, PartialEq)]
 #[builder(setter(into))]
 pub struct Bookmark {
     pub id: Option<i32>,
@@ -19,12 +19,18 @@ pub struct Bookmark {
     pub description: String,
     pub tags: HashSet<Tag>,
     pub access_count: i32,
-    pub created_at: DateTime<Utc>,
+    pub created_at: Option<DateTime<Utc>>,
     pub updated_at: DateTime<Utc>,
     pub embedding: Option<Vec<u8>>,
     pub content_hash: Option<Vec<u8>>,
-    #[builder(default = "false")] // Set default value to false
+    #[builder(default = "false")]
     pub embeddable: bool,
+    #[builder(default)]
+    pub file_path: Option<String>,
+    #[builder(default)]
+    pub file_mtime: Option<i32>,
+    #[builder(default)]
+    pub file_hash: Option<String>,
 }
 
 /// Methods for the Bookmark entity
@@ -51,22 +57,30 @@ impl Bookmark {
             description: description.as_ref().to_string(),
             tags,
             access_count: 0,
-            created_at: now,
+            created_at: Some(now),
             updated_at: now,
             embedding: None,
             content_hash: None,
             embeddable: false, // Default to false
+            file_path: None,
+            file_mtime: None,
+            file_hash: None,
         };
 
         // Get content for embedding using the structured method
         let content = bookmark.get_content_for_embedding();
 
-        bookmark.content_hash = Some(calc_content_hash(&content));
-        bookmark.embedding = embedder
+        let embedding_result = embedder
             .embed(&content)?
             .map(serialize_embedding)
             .transpose()?;
 
+        // Only set content_hash if an embedding is created
+        if embedding_result.is_some() {
+            bookmark.embedding = embedding_result;
+            bookmark.content_hash = Some(calc_content_hash(&content));
+        }
+
         Ok(bookmark)
     }
 
@@ -78,11 +92,14 @@ impl Bookmark {
         description: String,
         tag_string: String,
         access_count: i32,
-        created_at: DateTime<Utc>,
+        created_at: Option<DateTime<Utc>>,
         updated_at: DateTime<Utc>,
         embedding: Option<Vec<u8>>,
         content_hash: Option<Vec<u8>>,
-        embeddable: bool, // New parameter
+        embeddable: bool,
+        file_path: Option<String>,
+        file_mtime: Option<i32>,
+        file_hash: Option<String>,
     ) -> DomainResult<Self> {
         let tags = Tag::parse_tags(tag_string)?;
 
@@ -98,6 +115,9 @@ impl Bookmark {
             embedding,
             content_hash,
             embeddable,
+            file_path,
+            file_mtime,
+            file_hash,
         })
     }
 
@@ -304,14 +324,31 @@ impl fmt::Display for Bookmark {
     }
 }
 
+impl fmt::Debug for Bookmark {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        f.debug_struct("Bookmark")
+            .field("id", &self.id)
+            .field("url", &self.url)
+            .field("title", &self.title)
+            .field("description", &self.description)
+            .field("tags", &self.tags)
+            .field("access_count", &self.access_count)
+            .field("created_at", &self.created_at)
+            .field("updated_at", &self.updated_at)
+            .field("embedding", &self.embedding.as_ref().map(|_| "[...]"))
+            .field("content_hash", &self.content_hash)
+            .field("embeddable", &self.embeddable)
+            .finish()
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::app_state::AppState;
     use crate::util::testing::init_test_env;
 
     #[test]
-    fn test_new_bookmark_valid() {
+    fn given_valid_bookmark_data_when_new_then_creates_bookmark() {
         let _ = init_test_env();
         let mut tags = HashSet::new();
         tags.insert(Tag::new("test").unwrap());
@@ -321,7 +358,7 @@ mod tests {
             "Example Site",
             "An example website",
             tags,
-            AppState::read_global().context.embedder.as_ref(),
+            &crate::infrastructure::embeddings::DummyEmbedding,
         )
         .unwrap();
 
@@ -334,7 +371,7 @@ mod tests {
     }
 
     #[test]
-    fn test_special_urls_are_valid() {
+    fn given_special_urls_when_validate_then_accepts_as_valid() {
         let _ = init_test_env();
         let tags = HashSet::new();
 
@@ -344,7 +381,7 @@ mod tests {
             "Shell Command",
             "A shell command",
             tags.clone(),
-            AppState::read_global().context.embedder.as_ref(),
+            &crate::infrastructure::embeddings::DummyEmbedding,
         );
         assert!(shell_url.is_ok());
 
@@ -354,7 +391,7 @@ mod tests {
             "File Path",
             "A file path",
             tags.clone(),
-            AppState::read_global().context.embedder.as_ref(),
+            &crate::infrastructure::embeddings::DummyEmbedding,
         );
         assert!(file_url.is_ok());
 
@@ -364,13 +401,13 @@ mod tests {
             "Home Path",
             "A path in home directory",
             tags,
-            AppState::read_global().context.embedder.as_ref(),
+            &crate::infrastructure::embeddings::DummyEmbedding,
         );
         assert!(home_url.is_ok());
     }
 
     #[test]
-    fn test_add_remove_tags() {
+    fn given_bookmark_when_add_remove_tags_then_updates_tag_set() {
         let _ = init_test_env();
         let mut tags = HashSet::new();
         tags.insert(Tag::new("initial").unwrap());
@@ -380,7 +417,7 @@ mod tests {
             "Example Site",
             "An example website",
             tags,
-            AppState::read_global().context.embedder.as_ref(),
+            &crate::infrastructure::embeddings::DummyEmbedding,
         )
         .unwrap();
 
@@ -400,7 +437,7 @@ mod tests {
     }
 
     #[test]
-    fn test_set_tags() {
+    fn given_bookmark_when_set_tags_then_replaces_tag_set() {
         let _ = init_test_env();
         let mut tags = HashSet::new();
         tags.insert(Tag::new("initial").unwrap());
@@ -410,7 +447,7 @@ mod tests {
             "Example Site",
             "An example website",
             tags,
-            AppState::read_global().context.embedder.as_ref(),
+            &crate::infrastructure::embeddings::DummyEmbedding,
         )
         .unwrap();
 
@@ -425,7 +462,7 @@ mod tests {
     }
 
     #[test]
-    fn test_record_access() {
+    fn given_bookmark_when_record_access_then_increments_count() {
         let _ = init_test_env();
         let mut tags = HashSet::new();
         tags.insert(Tag::new("test").unwrap());
@@ -435,7 +472,7 @@ mod tests {
             "Example Site",
             "An example website",
             tags,
-            AppState::read_global().context.embedder.as_ref(),
+            &crate::infrastructure::embeddings::DummyEmbedding,
         )
         .unwrap();
 
@@ -449,7 +486,7 @@ mod tests {
     }
 
     #[test]
-    fn test_formatted_tags() {
+    fn given_bookmark_with_tags_when_format_then_returns_formatted_string() {
         let _ = init_test_env();
         let mut tags = HashSet::new();
         tags.insert(Tag::new("tag1").unwrap());
@@ -460,7 +497,7 @@ mod tests {
             "Example Site",
             "An example website",
             tags,
-            AppState::read_global().context.embedder.as_ref(),
+            &crate::infrastructure::embeddings::DummyEmbedding,
         )
         .unwrap();
 
@@ -469,7 +506,7 @@ mod tests {
     }
 
     #[test]
-    fn test_get_content_for_embedding() {
+    fn given_bookmark_when_get_embedding_content_then_returns_concatenated_text() {
         let _ = init_test_env();
         let mut tags = HashSet::new();
         tags.insert(Tag::new("visible").unwrap());
@@ -480,7 +517,7 @@ mod tests {
             "Example Site",
             "An example website",
             tags,
-            AppState::read_global().context.embedder.as_ref(),
+            &crate::infrastructure::embeddings::DummyEmbedding,
         )
         .unwrap();
 
@@ -492,7 +529,7 @@ mod tests {
     }
 
     #[test]
-    fn test_tag_matching() {
+    fn given_bookmark_with_tags_when_match_then_validates_tag_presence() {
         let _ = init_test_env();
         let mut bookmark_tags = HashSet::new();
         bookmark_tags.insert(Tag::new("tag1").unwrap());
@@ -504,7 +541,7 @@ mod tests {
             "Example Site",
             "An example website",
             bookmark_tags,
-            AppState::read_global().context.embedder.as_ref(),
+            &crate::infrastructure::embeddings::DummyEmbedding,
         )
         .unwrap();
 
@@ -547,7 +584,7 @@ mod tests {
     }
 
     #[test]
-    fn test_get_system_tags() {
+    fn given_bookmark_with_mixed_tags_when_get_system_tags_then_filters_system_only() {
         let _ = init_test_env();
         let mut tags = HashSet::new();
 
@@ -566,7 +603,7 @@ mod tests {
             "Example Site",
             "An example website",
             tags,
-            AppState::read_global().context.embedder.as_ref(),
+            &crate::infrastructure::embeddings::DummyEmbedding,
         )
         .unwrap();
 
@@ -580,7 +617,7 @@ mod tests {
     }
 
     #[test]
-    fn test_get_tags() {
+    fn given_bookmark_with_mixed_tags_when_get_tags_then_filters_user_only() {
         let _ = init_test_env();
         let mut tags = HashSet::new();
 
@@ -598,7 +635,7 @@ mod tests {
             "Example Site",
             "An example website",
             tags,
-            AppState::read_global().context.embedder.as_ref(),
+            &crate::infrastructure::embeddings::DummyEmbedding,
         )
         .unwrap();
 
@@ -613,7 +650,7 @@ mod tests {
     }
 
     #[test]
-    fn test_get_tags_with_only_system_tags() {
+    fn given_bookmark_with_only_system_tags_when_get_tags_then_returns_empty() {
         let _ = init_test_env();
         let mut tags = HashSet::new();
 
@@ -626,7 +663,7 @@ mod tests {
             "Example Site",
             "An example website",
             tags,
-            AppState::read_global().context.embedder.as_ref(),
+            &crate::infrastructure::embeddings::DummyEmbedding,
         )
         .unwrap();
 
@@ -640,7 +677,7 @@ mod tests {
     }
 
     #[test]
-    fn test_embeddable_flag() {
+    fn given_bookmark_when_set_embeddable_then_updates_flag() {
         let _ = init_test_env();
         let mut tags = HashSet::new();
         tags.insert(Tag::new("test").unwrap());
@@ -650,7 +687,7 @@ mod tests {
             "Example Site",
             "An example website",
             tags,
-            AppState::read_global().context.embedder.as_ref(),
+            &crate::infrastructure::embeddings::DummyEmbedding,
         )
         .unwrap();
 
@@ -666,7 +703,7 @@ mod tests {
         assert!(!bookmark.embeddable);
     }
     #[test]
-    fn test_is_system_tag() {
+    fn given_tag_when_check_system_then_validates_system_status() {
         let _ = init_test_env();
 
         // Create a bookmark with the Text system tag
@@ -678,7 +715,7 @@ mod tests {
             "Example Site",
             "An example website",
             tags,
-            AppState::read_global().context.embedder.as_ref(),
+            &crate::infrastructure::embeddings::DummyEmbedding,
         )
         .unwrap();
 
@@ -688,7 +725,7 @@ mod tests {
     }
 
     #[test]
-    fn test_is_uri() {
+    fn given_string_when_check_uri_then_validates_uri_format() {
         let _ = init_test_env();
 
         // Create a regular URI bookmark
@@ -698,7 +735,7 @@ mod tests {
             "Example Site",
             "A website with no system tags",
             tags_uri,
-            AppState::read_global().context.embedder.as_ref(),
+            &crate::infrastructure::embeddings::DummyEmbedding,
         )
         .unwrap();
 
@@ -710,7 +747,7 @@ mod tests {
             "Python Snippet",
             "A Python code snippet",
             tags_snippet,
-            AppState::read_global().context.embedder.as_ref(),
+            &crate::infrastructure::embeddings::DummyEmbedding,
         )
         .unwrap();
 
@@ -720,7 +757,7 @@ mod tests {
     }
 
     #[test]
-    fn test_get_action_content() {
+    fn given_bookmark_when_get_action_content_then_returns_appropriate_content() {
         let _ = init_test_env();
 
         // Create a URI bookmark
@@ -730,7 +767,7 @@ mod tests {
             "Example Site",
             "A website",
             tags_uri,
-            AppState::read_global().context.embedder.as_ref(),
+            &crate::infrastructure::embeddings::DummyEmbedding,
         )
         .unwrap();
 
@@ -743,7 +780,7 @@ mod tests {
             "Python Snippet",
             "A Python code snippet",
             tags_snippet,
-            AppState::read_global().context.embedder.as_ref(),
+            &crate::infrastructure::embeddings::DummyEmbedding,
         )
         .unwrap();
 
